#
# spec file for package python-google-cloud-spanner
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-google-cloud-spanner%{psuffix}
Version:        3.53.0
Release:        1.1
Summary:        Google Cloud Spanner API client library
License:        Apache-2.0
URL:            https://github.com/googleapis/python-spanner
Source:         https://files.pythonhosted.org/packages/source/g/google_cloud_spanner/google_cloud_spanner-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  python-rpm-macros
# SECTION test requirements
%if %{with test}
BuildRequires:  %{python_module google-cloud-monitoring >= 2.16.0}
BuildRequires:  %{python_module google-cloud-spanner = %{version}}
BuildRequires:  %{python_module mmh3 >= 4.1.0}
BuildRequires:  %{python_module opentelemetry-api >= 1.22.0}
BuildRequires:  %{python_module opentelemetry-resourcedetector-gcp >= 1.8.0a0}
BuildRequires:  %{python_module opentelemetry-sdk >= 1.22.0}
BuildRequires:  %{python_module opentelemetry-semantic-conventions >= 0.43b0}
BuildRequires:  %{python_module pytest-asyncio}
BuildRequires:  %{python_module pytest}
%endif
# /SECTION
BuildRequires:  fdupes
Requires:       python-google-api-core >= 1.34.0
Requires:       python-google-cloud-core >= 1.4.4
Requires:       python-grpc-google-iam-v1 >= 0.12.4
Requires:       python-grpc-interceptor >= 0.15.4
Requires:       python-proto-plus >= 1.22.0
Requires:       python-protobuf >= 3.20.2
Requires:       python-sqlparse >= 0.4.4
Suggests:       python-google-cloud-monitoring >= 2.16.0
Suggests:       python-mmh3 >= 4.1.0
Suggests:       python-libcst >= 0.2.5
Suggests:       python-opentelemetry-api >= 1.22.0
Suggests:       python-opentelemetry-sdk >= 1.22.0
Suggests:       python-opentelemetry-semantic-conventions >= 0.43b0
Suggests:       python-opentelemetry-resourcedetector-gcp >= 1.8.0a0
Suggests:       python-opentelemetry-instrumentation >= 0.20b0
BuildArch:      noarch
%python_subpackages

%description
Google Cloud Spanner API client library

%prep
%autosetup -p1 -n google_cloud_spanner-%{version}

# don't use python-mock
for i in $(find tests -name "*.py")
do
  sed -i 's/^import mock/from unittest import mock/g' $i
done

%build
%pyproject_wheel

%install
%if %{without test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%check
%if %{with test}
mkdir -p $HOME/.config/gcloud
cat > $HOME/.config/gcloud/application_default_credentials.json <<EOF
{
  "client_id": "111111111111-1qq1q1qq1qqq111qq1qqqq11q1qqqqqq.apps.googleusercontent.com",
  "client_secret": "d-XXXXXXXXXXXXXXXXXXXXXX",
  "refresh_token": "1//1111111111111111111111111111-XXXXXXXXX-AAAAAAAAAAA_BBBBBBBBBBBBBBBBBBBBBB-CCCCCCCCCCCCCCCCCCCCCCCCCC",
  "type": "authorized_user"
}
EOF
export GOOGLE_CLOUD_PROJECT="PROJECT"
%pytest -x tests/unit
%endif

%if %{without test}
%files %{python_files}
%doc README.rst
%license LICENSE
%pycache_only %{python_sitelib}/google/cloud/__pycache__
%dir %{python_sitelib}/google
%dir %{python_sitelib}/google/cloud
%{python_sitelib}/google/cloud/spanner*
%{python_sitelib}/google_cloud_spanner-%{version}.dist-info
%endif

%changelog
* Mon Apr 28 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Add missing test dependencies to BuildRequires
* Sat Apr 26 2025 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 3.53.0
  * Add AddSplitPoints API
  * Add Attempt, Operation and GFE Metrics (#1302)
  * Add REST Interceptors which support reading metadata
  * Add support for opt-in debug logging
  * Add support for reading selective GAPIC generation methods from service YAML
  * Add the last statement option to ExecuteSqlRequest and ExecuteBatchDmlRequest
  * Add UUID in Spanner TypeCode enum
  * End to end tracing (#1315)
  * Exposing FreeInstanceAvailability in InstanceConfig
  * Exposing FreeInstanceMetadata in Instance configuration
    (to define the metadata related to FREE instance type)
  * Exposing InstanceType in Instance configuration
    (to define PROVISIONED or FREE spanner instance)
  * Exposing QuorumType in InstanceConfig
  * Exposing storage_limit_per_processing_unit in InstanceConfig
  * Snapshot isolation (#1318)
  * **spanner:** A new enum `IsolationLevel` is added (#1224)
  * Allow Protobuf 6.x (#1320)
  * Cleanup after metric integration test (#1322)
  * **deps:** Require grpc-google-iam-v1 >= 0.14.0
  * Fix typing issue with gRPC metadata when key ends in -bin
  * Add option for last_statement (#1313)
  * A comment for enum `DefaultBackupScheduleType` is changed
  * A comment for enum value `AUTOMATIC` in enum `DefaultBackupScheduleType` is changed
  * A comment for enum value `GOOGLE_MANAGED` in enum `Type` is changed
  * A comment for enum value `NONE` in enum `DefaultBackupScheduleType` is changed
  * A comment for enum value `USER_MANAGED` in enum `Type` is changed
  * A comment for field `base_config` in message
    `.google.spanner.admin.instance.v1.InstanceConfig` is changed
  * A comment for field `default_backup_schedule_type` in message
    `.google.spanner.admin.instance.v1.Instance`
  * A comment for field `filter` in message
    `.google.spanner.admin.instance.v1.ListInstanceConfigOperationsRequest`
    is changed
  * A comment for field `filter` in message
    `.google.spanner.admin.instance.v1.ListInstancePartitionOperationsRequest`
    is changed
  * A comment for field `instance_config` in message
    `.google.spanner.admin.instance.v1.CreateInstanceConfigRequest`
    is changed
  * A comment for field `instance_partition_deadline` in message
    `.google.spanner.admin.instance.v1.ListInstancePartitionOperationsRequest`
    is changed
  * A comment for field `location` in message
    `.google.spanner.admin.instance.v1.ReplicaInfo` is changed
  * A comment for field `node_count` in message
    `.google.spanner.admin.instance.v1.Instance` is changed
  * A comment for field `node_count` in message
    `.google.spanner.admin.instance.v1.InstancePartition` is changed
  * A comment for field `operations` in message
    `.google.spanner.admin.instance.v1.ListInstanceConfigOperationsResponse`
    is changed
  * A comment for field `operations` in message
    `.google.spanner.admin.instance.v1.ListInstancePartitionOperationsResponse`
    is changed
  * A comment for field `optional_replicas` in message
    `.google.spanner.admin.instance.v1.InstanceConfig` is changed
  * A comment for field `parent` in message
    `.google.spanner.admin.instance.v1.ListInstancePartitionsRequest` is changed
  * A comment for field `processing_units` in message
    `.google.spanner.admin.instance.v1.Instance` is changed
  * A comment for field `processing_units` in message
    `.google.spanner.admin.instance.v1.InstancePartition` is changed
  * A comment for field `referencing_backups` in message
    `.google.spanner.admin.instance.v1.InstancePartition` is changed
  * A comment for field `replicas` in message
    `.google.spanner.admin.instance.v1.InstanceConfig` is changed
  * A comment for field `storage_utilization_percent` in message
    `.google.spanner.admin.instance.v1.AutoscalingConfig` is changed
  * A comment for field `unreachable` in message
    `.google.spanner.admin.instance.v1.ListInstancePartitionsResponse` is changed
  * A comment for message `CreateInstanceConfigRequest` is changed
  * A comment for message `DeleteInstanceConfigRequest` is changed
  * A comment for message `UpdateInstanceConfigRequest` is changed
  * A comment for method `CreateInstance` in service `InstanceAdmin` is changed
  * A comment for method `CreateInstanceConfig` in service `InstanceAdmin` is changed
  * A comment for method `CreateInstancePartition` in service `InstanceAdmin` is changed
  * A comment for method `ListInstanceConfigOperations` in service `InstanceAdmin` is changed
  * A comment for method `ListInstanceConfigs` in service `InstanceAdmin` is changed
  * A comment for method `ListInstancePartitionOperations` in service `InstanceAdmin` is changed
  * A comment for method `MoveInstance` in service `InstanceAdmin` is changed
  * A comment for method `UpdateInstance` in service `InstanceAdmin` is changed
  * A comment for method `UpdateInstanceConfig` in service `InstanceAdmin` is changed
  * A comment for method `UpdateInstancePartition` in service `InstanceAdmin` is changed
  * Fix typo timzeone -> timezone
- from version 3.52.0
  * Add additional opentelemetry span events for session pool
  * Add GCP standard otel attributes for python client (#1308)
  * Add updated span events + trace more methods (#1259)
  * MetricsTracer implementation (#1291)
  * Support GRAPH and pipe syntax in dbapi (#1285)
  * Support transaction and request tags in dbapi (#1262)
  * **x-goog-spanner-request-id:** Introduce AtomicCounter (#1275)
  * Retry UNAVAILABLE errors for streaming RPCs (#1278)
  * **tracing:** Ensure nesting of Transaction.begin under commit
    + fix suggestions from feature review (#1287)
  * **tracing:** Only set span.status=OK if UNSET (#1248)
  * Update retry strategy for mutation calls to handle aborted transactions (#1279)
- from version 3.51.0
  * Add connection variable for ignoring transaction warnings (#1249)
  * **spanner:** Implement custom tracer_provider injection for opentelemetry traces (#1229)
  * Support float32 parameters in dbapi (#1245)
  * Allow setting connection.read_only to same value (#1247)
  * Allow setting staleness to same value in tx (#1253)
  * Dbapi raised AttributeError with [] as arguments (#1257)
  * Optimize ResultSet decoding (#1244)
  * Remove repeated GetSession calls for FixedSizePool (#1252)
  * **samples:** Add samples for Cloud Spanner Default Backup Schedules (#1238)
- Update Suggests from setup.py
* Mon Nov 18 2024 Markéta Machová <mmachova@suse.com>
- Update to 3.50.1
  * Add BatchWrite API
  * spanner: Add autoscaling config to the instance proto
  * spanner: Add directed_read_option in spanner.proto
  * Add max_commit_delay API
  * Exposing Spanner client in dbapi connection
  * Add support of float32 type
  * Add support for PG.OID in parameterized queries
  * spanner: Adding EXPECTED_FULFILLMENT_PERIOD to the indicate instance creation times
  * Add support for Cloud Spanner Scheduled Backups
  * spanner: Add support for Cloud Spanner Default Backup Schedules
  * many more changes, see upstream CHANGELOG.md
* Wed Jan 10 2024 Daniel Garcia <daniel.garcia@suse.com>
- Run tests using multibuild
- Add google and google/cloud folders to package ownership
* Tue Jan  9 2024 Daniel Garcia <daniel.garcia@suse.com>
- Initial version 3.40.1 (jsc#PED-6697)
